@@ -47,6 +47,7 @@ reserved = {
     'package': 'PACKAGE',
     'subpackage': 'SUBPACKAGE',
     'exclude': 'EXCLUDE',
+    'context': 'CONTEXT',
 }
 
 tokens = (
@@ -86,7 +87,7 @@ def t_ATOM(t):
 
 def t_QUOTEDSTRING(t):
     r'\"([^\\\n]|(\\.))*?\"'
-    t.value = t.value[1:-1]
+    t.value = t.value[1:-1].replace('\\"', '"')
     return t
 
 def t_TRIQUOTEDSTRING(t):
@@ -109,9 +110,11 @@ def t_error(t):
 
 
 def p_manifest(t):
-    '''manifest : package subpackages excludes'''
+    '''manifest : package subpackages excludes context'''
+    options = t[4].copy()
+    options.update(t[1].options)
     t[0] = Package(name=t[1].name,
-                   options=t[1].options,
+                   options=options,
                    files=t[1].files,
                    description=t[1].description,
                    subpackages=t[2],
@@ -172,7 +175,7 @@ def p_subpackage(t):
 
 def p_excludes(t):
     '''excludes : empty
-              | exclude excludes'''
+                | exclude excludes'''
     if len(t) == 2:
         t[0] = []
     elif len(t) == 3:
@@ -180,6 +183,16 @@ def p_excludes(t):
     else:
         assert False
 
+def p_context(t):
+    '''context : empty
+               | CONTEXT package_options'''
+    if len(t) == 2:
+        t[0] = {}
+    elif len(t) == 3:
+        t[0] = t[2]
+    else:
+        assert False
+
 def p_exclude(t):
     '''exclude : EXCLUDE NOSPACESTRING'''
     t[0] = t[2]
